algo.colors <- c(cghseg.k="#F8766D",
                 "cghseg.k, pelt.n"="#F8766D",
                 pelt.n="#F8766D",
                 flsa.norm="#619CFF",
                 flsa="#00BA38",
                 gada="#361eed",
                 dnacopy.alpha="#D39200",
                 dnacopy.prune="#00C19F",
                 dnacopy.sd="#DB72FB",
                 glad.haarseg="#93AA00",
                 glad.lambdabreak="#00B9E3",
                 glad.MinBkpWeight="#FF61C3",
                 pelt.default="#FFFFFF",
                 gada.default="#FFFFFF",
                 glad.default="#FFFFFF",
                 dnacopy.default="#FFFFFF",
                 cghseg.mBIC="#FFFFFF",
                 cghFLasso="#FFFFFF")
